package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.TdQuestion;

/**
 * 题库管理Service接口
 * 
 * @author admin
 * @date 2024-04-07
 */
public interface ITdQuestionService 
{
    /**
     * 查询题库管理
     * 
     * @param ID 题库管理主键
     * @return 题库管理
     */
    public TdQuestion selectTdQuestionByID(Long ID);

    /**
     * 查询题库管理列表
     * 
     * @param tdQuestion 题库管理
     * @return 题库管理集合
     */
    public List<TdQuestion> selectTdQuestionList(TdQuestion tdQuestion);

    /**
     * 新增题库管理
     * 
     * @param tdQuestion 题库管理
     * @return 结果
     */
    public int insertTdQuestion(TdQuestion tdQuestion);

    /**
     * 修改题库管理
     * 
     * @param tdQuestion 题库管理
     * @return 结果
     */
    public int updateTdQuestion(TdQuestion tdQuestion);

    /**
     * 批量删除题库管理
     * 
     * @param IDs 需要删除的题库管理主键集合
     * @return 结果
     */
    public int deleteTdQuestionByIDs(String IDs);

    /**
     * 删除题库管理信息
     * 
     * @param ID 题库管理主键
     * @return 结果
     */
    public int deleteTdQuestionByID(Long ID);
}
